==> phpAdsNew-2.0.tar.gz: phpAdsNew-2.0/language/german/invocation.lang.php <==
<?php // $Revision: 1.1.2.4 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2003 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


// German
// Invocation Types
$GLOBALS['strInvocationRemote']		= "Normaler Bannercode (Remote)";
$GLOBALS['strInvocationJS']			= "Bannercode fr JavaScript";
$GLOBALS['strInvocationIframes']		= "Bannercode fr Frames (iframe/ilayer)";
$GLOBALS['strInvocationXmlRpc']		= "Bannercode bei Nutzung von XML-RPC"; 
$GLOBALS['strInvocationCombined']		= "Kombinierter Bannercode";
$GLOBALS['strInvocationPopUp']			= "PopUp";
$GLOBALS['strInvocationAdLayer']		= "Interstitial oder Floating DHTML";
$GLOBALS['strInvocationLocal']			= "Lokaler Modus";


// Other
$GLOBALS['strCopyToClipboard']			= "Kopieren in Zwischenablage";


// Measures
$GLOBALS['strAbbrPixels']			= "Px";
$GLOBALS['strAbbrSeconds']			= "Sek";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Bannerauswahl";
$GLOBALS['strInvocationClientID']		= "Inserent oder Kampagne";
$GLOBALS['strInvocationTarget']			= "Zielfenster (target frame)";
$GLOBALS['strInvocationSource']			= "Quelle";
$GLOBALS['strInvocationWithText']		= "Textanzeige unterhalb Banner";
$GLOBALS['strInvocationDontShowAgain']		= "Banner auf derselben Seite nicht mehrfach anzeigen";
$GLOBALS['strInvocationDontShowAgainCampaign']		= "Banner derselben Kampagne nicht mehrfach auf derselben Seite anzeigen";
$GLOBALS['strInvocationTemplate'] 		= "Um Templates nutzen zu knnen, Banner in einer Variablen speichern";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Erneuern (refresh) nach ";
$GLOBALS['strIframeResizeToBanner']		= "Iframe an die Bannergre anpassen";
$GLOBALS['strIframeMakeTransparent']		= "Iframe transparent darstellen";
$GLOBALS['strIframeIncludeNetscape4']		= "Netscape 4 kompatiblen ilayer (zustzlich)";


// PopUp
$GLOBALS['strPopUpStyle']			= "PopUp Type";
$GLOBALS['strPopUpStylePopUp']		= "PopUp";
$GLOBALS['strPopUpStylePopUnder']		= "PopUnder";
$GLOBALS['strPopUpCreateInstance']		= "Zeitpunkt zu dem das PopUp erscheinen wird";
$GLOBALS['strPopUpImmediately']		= "Sofort";
$GLOBALS['strPopUpOnClose']			= "Wenn die Seite geschlossen wird";
$GLOBALS['strPopUpAfterSec']			= "Nach";
$GLOBALS['strAutoCloseAfter']			= "Schliet automatisch nach";
$GLOBALS['strPopUpTop']			= "Startposition (oben)";
$GLOBALS['strPopUpLeft']			= "Startposition (links)";
$GLOBALS['strWindowOptions']			= "Window-Optionen";
$GLOBALS['strShowToolbars']			= "Werkzeugleiste";
$GLOBALS['strShowLocation']			= "Standortleiste";
$GLOBALS['strShowMenubar']			= "Menleiste";
$GLOBALS['strShowStatus']			= "Statusleiste";
$GLOBALS['strWindowResizable']		= "Gre anpassen";
$GLOBALS['strShowScrollbars']			= "Scroll-Leiste";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Sprache auf Host";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "Style";

$GLOBALS['strAlignment']			= "Ausrichtung";
$GLOBALS['strHAlignment']			= "Horizontale Ausrichtung";
$GLOBALS['strLeft']				= "Links";
$GLOBALS['strCenter']				= "Zentriert";
$GLOBALS['strRight']				= "Rechts";

$GLOBALS['strVAlignment']			= "Vertikale Ausrichtung";
$GLOBALS['strTop']				= "Oben";
$GLOBALS['strMiddle']				= "Mitte";
$GLOBALS['strBottom']				= "Unten";

$GLOBALS['strAutoCollapseAfter']		= "Automatisch einklappen nach";
$GLOBALS['strCloseText']			= "Schlietext";
$GLOBALS['strClose']				= "[Schlieen]";
$GLOBALS['strBannerPadding']			= "Banner ausfllen";

$GLOBALS['strHShift']				= "Horizontal verschieben";
$GLOBALS['strVShift']				= "Vertikal verschieben";

$GLOBALS['strShowCloseButton']		= "Anzeigen Ende-Button";
$GLOBALS['strBackgroundColor']		= "Hintergrundfarbe";
$GLOBALS['strBorderColor']			= "Farbe des Randes";

$GLOBALS['strDirection']			= "Richtung";
$GLOBALS['strLeftToRight']			= "Links nach rechts";
$GLOBALS['strRightToLeft']			= "Rechts nach links";
$GLOBALS['strLooping']				= "Schleifen";
$GLOBALS['strAlwaysActive']			= "Immer aktiv";
$GLOBALS['strSpeed']				= "Geschwindigkeit";
$GLOBALS['strPause']				= "Pause";
$GLOBALS['strLimited']				= "Limitiert";
$GLOBALS['strLeftMargin']			= "Linker Rand";
$GLOBALS['strRightMargin']			= "Rechter Rand";
$GLOBALS['strTransparentBackground']		= "Transparenter Hintergrund";

$GLOBALS['strSmoothMovement']		= "Ruhige Bewegung";
$GLOBALS['strHideNotMoving']			= "Verberge Banner, wenn Cursor nicht bewegt wird";
$GLOBALS['strHideDelay']			= "Verzgerung bis zum Verbergen des Banners";
$GLOBALS['strHideTransparancy']		= "Transparenz des verborgenen Banners";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Einfach",
	'cursor'		=> "Cursor",
	'floater'		=> "Floater"
);

?>

==> phpAdsNew-2.0.7.tar.gz: phpAdsNew-2.0.7/language/german/invocation.lang.php <==
<?php // $Revision: 1.1.2.4 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2005 by the phpAdsNew developers                  */
/* For more information visit: http://www.phpadsnew.com                 */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/


// German
// Invocation Types
$GLOBALS['strInvocationRemote']		= "Normaler Bannercode (Remote)";
$GLOBALS['strInvocationJS']			= "Bannercode fr JavaScript";
$GLOBALS['strInvocationIframes']		= "Bannercode fr Frames (iframe/ilayer)";
$GLOBALS['strInvocationXmlRpc']		= "Bannercode bei Nutzung von XML-RPC"; 
$GLOBALS['strInvocationCombined']		= "Kombinierter Bannercode";
$GLOBALS['strInvocationPopUp']		= "PopUp";
$GLOBALS['strInvocationAdLayer']		= "Interstitial oder Floating DHTML";
$GLOBALS['strInvocationLocal']			= "Lokaler Modus";


// Other
$GLOBALS['strCopyToClipboard']			= "Kopieren in Zwischenablage";


// Measures
$GLOBALS['strAbbrPixels']			= "Px";
$GLOBALS['strAbbrSeconds']			= "Sek";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Bannerauswahl";
$GLOBALS['strInvocationClientID']		= "Inserent oder Kampagne";
$GLOBALS['strInvocationTarget']			= "Zielfenster (target frame)";
$GLOBALS['strInvocationSource']			= "Quelle";
$GLOBALS['strInvocationWithText']		= "Textanzeige unterhalb Banner";
$GLOBALS['strInvocationDontShowAgain']		= "Banner auf derselben Seite nicht mehrfach anzeigen";
$GLOBALS['strInvocationDontShowAgainCampaign']		= "Banner derselben Kampagne nicht mehrfach auf derselben Seite anzeigen";
$GLOBALS['strInvocationTemplate'] 		= "Um Templates nutzen zu knnen, Banner in einer Variablen speichern";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Erneuern (refresh) nach ";
$GLOBALS['strIframeResizeToBanner']		= "Iframe an die Bannergre anpassen";
$GLOBALS['strIframeMakeTransparent']		= "Iframe transparent darstellen";
$GLOBALS['strIframeIncludeNetscape4']		= "Netscape 4 kompatiblen ilayer (zustzlich)";


// PopUp
$GLOBALS['strPopUpStyle']			= "PopUp Type";
$GLOBALS['strPopUpStylePopUp']		= "PopUp";
$GLOBALS['strPopUpStylePopUnder']		= "PopUnder";
$GLOBALS['strPopUpCreateInstance']		= "Zeitpunkt zu dem das PopUp erscheinen wird";
$GLOBALS['strPopUpImmediately']		= "Sofort";
$GLOBALS['strPopUpOnClose']			= "Wenn die Seite geschlossen wird";
$GLOBALS['strPopUpAfterSec']			= "Nach";
$GLOBALS['strAutoCloseAfter']			= "Schliet automatisch nach";
$GLOBALS['strPopUpTop']			= "Startposition (oben)";
$GLOBALS['strPopUpLeft']			= "Startposition (links)";
$GLOBALS['strWindowOptions']			= "Fenster-Optionen";
$GLOBALS['strShowToolbars']			= "Werkzeugleiste";
$GLOBALS['strShowLocation']			= "Standortleiste";
$GLOBALS['strShowMenubar']			= "Menleiste";
$GLOBALS['strShowStatus']			= "Statusleiste";
$GLOBALS['strWindowResizable']		= "Gre anpassen";
$GLOBALS['strShowScrollbars']			= "Scroll-Leiste";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Sprache auf Host";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "Style";

$GLOBALS['strAlignment']			= "Ausrichtung";
$GLOBALS['strHAlignment']			= "Horizontale Ausrichtung";
$GLOBALS['strLeft']				= "Links";
$GLOBALS['strCenter']				= "Zentriert";
$GLOBALS['strRight']				= "Rechts";

$GLOBALS['strVAlignment']			= "Vertikale Ausrichtung";
$GLOBALS['strTop']				= "Oben";
$GLOBALS['strMiddle']				= "Mitte";
$GLOBALS['strBottom']				= "Unten";

$GLOBALS['strAutoCollapseAfter']		= "Automatisch einklappen nach";
$GLOBALS['strCloseText']			= "Schlietext";
$GLOBALS['strClose']				= "[Schlieen]";
$GLOBALS['strBannerPadding']			= "Banner ausfllen";

$GLOBALS['strHShift']				= "Horizontal verschieben";
$GLOBALS['strVShift']				= "Vertikal verschieben";

$GLOBALS['strShowCloseButton']		= "Anzeigen Ende-Button";
$GLOBALS['strBackgroundColor']		= "Hintergrundfarbe";
$GLOBALS['strBorderColor']			= "Farbe des Randes";

$GLOBALS['strDirection']			= "Richtung";
$GLOBALS['strLeftToRight']			= "Links nach rechts";
$GLOBALS['strRightToLeft']			= "Rechts nach links";
$GLOBALS['strLooping']				= "Schleifen";
$GLOBALS['strAlwaysActive']			= "Immer aktiv";
$GLOBALS['strSpeed']				= "Geschwindigkeit";
$GLOBALS['strPause']				= "Pause";
$GLOBALS['strLimited']				= "Limitiert";
$GLOBALS['strLeftMargin']			= "Linker Rand";
$GLOBALS['strRightMargin']			= "Rechter Rand";
$GLOBALS['strTransparentBackground']		= "Transparenter Hintergrund";

$GLOBALS['strSmoothMovement']		= "Ruhige Bewegung";
$GLOBALS['strHideNotMoving']			= "Verberge Banner, wenn Cursor nicht bewegt wird";
$GLOBALS['strHideDelay']			= "Verzgerung bis zum Verbergen des Banners";
$GLOBALS['strHideTransparancy']		= "Transparenz des verborgenen Banners";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Einfach",
	'cursor'		=> "Cursor",
	'floater'		=> "Floater"
);

?>
